==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/CreateCampaignRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class CreateCampaignRequest(
    applicationId: __string,
    writeCampaignRequest: zio.aws.pinpoint.model.WriteCampaignRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest = {
    import CreateCampaignRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .writeCampaignRequest(writeCampaignRequest.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.CreateCampaignRequest.ReadOnly =
    zio.aws.pinpoint.model.CreateCampaignRequest.wrap(buildAwsValue())
}
object CreateCampaignRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.CreateCampaignRequest =
      zio.aws.pinpoint.model
        .CreateCampaignRequest(applicationId, writeCampaignRequest.asEditable)
    def applicationId: __string
    def writeCampaignRequest
        : zio.aws.pinpoint.model.WriteCampaignRequest.ReadOnly
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getWriteCampaignRequest: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.WriteCampaignRequest.ReadOnly
    ] = ZIO.succeed(writeCampaignRequest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest
  ) extends zio.aws.pinpoint.model.CreateCampaignRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val writeCampaignRequest
        : zio.aws.pinpoint.model.WriteCampaignRequest.ReadOnly =
      zio.aws.pinpoint.model.WriteCampaignRequest
        .wrap(impl.writeCampaignRequest())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest
  ): zio.aws.pinpoint.model.CreateCampaignRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/CreateCampaignRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class CreateCampaignRequest(
    applicationId: __string,
    writeCampaignRequest: zio.aws.pinpoint.model.WriteCampaignRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest = {
    import CreateCampaignRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .writeCampaignRequest(writeCampaignRequest.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.CreateCampaignRequest.ReadOnly =
    zio.aws.pinpoint.model.CreateCampaignRequest.wrap(buildAwsValue())
}
object CreateCampaignRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.CreateCampaignRequest =
      zio.aws.pinpoint.model
        .CreateCampaignRequest(applicationId, writeCampaignRequest.asEditable)
    def applicationId: __string
    def writeCampaignRequest
        : zio.aws.pinpoint.model.WriteCampaignRequest.ReadOnly
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getWriteCampaignRequest: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.WriteCampaignRequest.ReadOnly
    ] = ZIO.succeed(writeCampaignRequest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest
  ) extends zio.aws.pinpoint.model.CreateCampaignRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val writeCampaignRequest
        : zio.aws.pinpoint.model.WriteCampaignRequest.ReadOnly =
      zio.aws.pinpoint.model.WriteCampaignRequest
        .wrap(impl.writeCampaignRequest())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.CreateCampaignRequest
  ): zio.aws.pinpoint.model.CreateCampaignRequest.ReadOnly = new Wrapper(impl)
}
